# [2.4.5](https://github.com/seriaati/enka-py/compare/v2.4.4..v2.4.5) - 2025-02-16

## Bug Fixes

-  [**breaking**]Fix typo in French enum name ([#90](https://github.com/seriaati/enka-py/issues/90)) - ([13de708](https://github.com/seriaati/enka-py/commit/13de708699ce49be2c245933d2ac641fb0e89a31))

## Documentation

- Update deprecation details - ([1d31382](https://github.com/seriaati/enka-py/commit/1d313822b5f902d53aa623649b1077cb042a19de))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#86](https://github.com/seriaati/enka-py/issues/86)) - ([86f0028](https://github.com/seriaati/enka-py/commit/86f0028ace31cee18158bd85c2725fdc44b62e83))
- **(deps)** lock file maintenance ([#87](https://github.com/seriaati/enka-py/issues/87)) - ([d7c4fbf](https://github.com/seriaati/enka-py/commit/d7c4fbfb7147e284a07fbeb14496691087d60ccc))
- **(deps)** lock file maintenance ([#88](https://github.com/seriaati/enka-py/issues/88)) - ([8073000](https://github.com/seriaati/enka-py/commit/80730008e1649b5d82ba45986fd16ef6592dee5c))
- **(deps)** lock file maintenance ([#89](https://github.com/seriaati/enka-py/issues/89)) - ([2908b41](https://github.com/seriaati/enka-py/commit/2908b41791cc4c75045127f3f661223de7690a67))
- Update lock file - ([275a865](https://github.com/seriaati/enka-py/commit/275a865c3178033da16d6d1990ccfdc3a42e2064))

